@@ -44,11 +44,7 @@ import org.junit.Assert;
 /**
  * This is used to test FileUtils for correctness.
  *
- * @author Peter Donald
- * @author Matthew Hawthorne
- * @author Stephen Colebourne
- * @author Jim Harrington
- * @version $Id: FileUtilsTestCase.java 1163295 2011-08-30 17:22:38Z ggregory $
+ * @version $Id: FileUtilsTestCase.java 1308108 2012-04-01 13:30:34Z ggregory $
  * @see FileUtils
  */
 public class FileUtilsTestCase extends FileBasedTestCase {
@@ -232,7 +228,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
             } finally {
                 IOUtils.closeQuietly(out);
             }
-            assertEquals(true, file.exists());
+            assertTrue(file.exists());
         } finally {
             if (file.delete() == false) {
                 file.deleteOnExit();
@@ -259,7 +255,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         } finally {
             IOUtils.closeQuietly(out);
         }
-        assertEquals(true, file.exists());
+        assertTrue(file.exists());
     }
 
     public void test_openOutputStream_existsButIsDirectory() throws Exception {
@@ -285,7 +281,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         } finally {
             IOUtils.closeQuietly(out);
         }
-        assertEquals(true, file.exists());
+        assertTrue(file.exists());
     }
 
     public void test_openOutputStream_notExistsCannotCreate() throws Exception {
@@ -323,11 +319,11 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         assertEquals(FileUtils.byteCountToDisplaySize(1024 * 1024 * 1023), "1023 MB");
         assertEquals(FileUtils.byteCountToDisplaySize(1024 * 1024 * 1024), "1 GB");
         assertEquals(FileUtils.byteCountToDisplaySize(1024 * 1024 * 1025), "1 GB");
-        assertEquals(FileUtils.byteCountToDisplaySize((1024 * 1024 * 1024 * 2) - 1), "1 GB");
-//        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024), "1 TB");
-//        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024 * 1024), "1 PB");
-//        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024 * 1024 * 1024), "1 EB");
-//        assertEquals(FileUtils.byteCountToDisplaySize(Long.MAX_VALUE), "7 EB");
+        assertEquals(FileUtils.byteCountToDisplaySize(1024 * 1024 * 1024 * 2 - 1), "1 GB");
+        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024), "1 TB");
+        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024 * 1024), "1 PB");
+        assertEquals(FileUtils.byteCountToDisplaySize(1024L * 1024 * 1024 * 1024 * 1024 * 1024), "1 EB");
+        assertEquals(FileUtils.byteCountToDisplaySize(Long.MAX_VALUE), "7 EB");
         // Other MAX_VALUEs
         assertEquals(FileUtils.byteCountToDisplaySize(Character.MAX_VALUE), "63 KB");
         assertEquals(FileUtils.byteCountToDisplaySize(Short.MAX_VALUE), "31 KB");
@@ -338,13 +334,13 @@ public class FileUtilsTestCase extends FileBasedTestCase {
     public void testToFile1() throws Exception {
         URL url = new URL("file", null, "a/b/c/file.txt");
         File file = FileUtils.toFile(url);
-        assertEquals(true, file.toString().indexOf("file.txt") >= 0);
+        assertTrue(file.toString().indexOf("file.txt") >= 0);
     }
 
     public void testToFile2() throws Exception {
         URL url = new URL("file", null, "a/b/c/file%20n%61me%2520.tx%74");
         File file = FileUtils.toFile(url);
-        assertEquals(true, file.toString().indexOf("file name%20.txt") >= 0);
+        assertTrue(file.toString().indexOf("file name%20.txt") >= 0);
     }
 
     public void testToFile3() throws Exception {
@@ -355,7 +351,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
     public void testToFile4() throws Exception {
         URL url = new URL("file", null, "a/b/c/file%%20%me.txt%");
         File file = FileUtils.toFile(url);
-        assertEquals(true, file.toString().indexOf("file% %me.txt%") >= 0);
+        assertTrue(file.toString().indexOf("file% %me.txt%") >= 0);
     }
 
     /** IO-252 */
@@ -367,7 +363,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
     public void testToFileUtf8() throws Exception {
         URL url = new URL("file", null, "/home/%C3%A4%C3%B6%C3%BC%C3%9F");
         File file = FileUtils.toFile(url);
-        assertEquals(true, file.toString().indexOf("\u00E4\u00F6\u00FC\u00DF") >= 0);
+        assertTrue(file.toString().indexOf("\u00E4\u00F6\u00FC\u00DF") >= 0);
     }
 
     public void testDecodeUrl() {
@@ -452,14 +448,14 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         URL[] urls = FileUtils.toURLs(files);
         
         assertEquals(files.length, urls.length);
-        assertEquals(true, urls[0].toExternalForm().startsWith("file:"));
-        assertEquals(true, urls[0].toExternalForm().indexOf("file1.txt") >= 0);
-        assertEquals(true, urls[1].toExternalForm().startsWith("file:"));
-        assertEquals(true, urls[1].toExternalForm().indexOf("file2.txt") >= 0);
+        assertTrue(urls[0].toExternalForm().startsWith("file:"));
+        assertTrue(urls[0].toExternalForm().indexOf("file1.txt") >= 0);
+        assertTrue(urls[1].toExternalForm().startsWith("file:"));
+        assertTrue(urls[1].toExternalForm().indexOf("file2.txt") >= 0);
 
         // Test escaped char
-        assertEquals(true, urls[2].toExternalForm().startsWith("file:"));
-        assertEquals(true, urls[2].toExternalForm().indexOf("test%20file.txt") >= 0);
+        assertTrue(urls[2].toExternalForm().startsWith("file:"));
+        assertTrue(urls[2].toExternalForm().indexOf("test%20file.txt") >= 0);
     }
 
 //    public void testToURLs2() throws Exception {
@@ -470,8 +466,8 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 //        URL[] urls = FileUtils.toURLs(files);
 //        
 //        assertEquals(files.length, urls.length);
-//        assertEquals(true, urls[0].toExternalForm().startsWith("file:"));
-//        assertEquals(true, urls[0].toExternalForm().indexOf("file1.txt") > 0);
+//        assertTrue(urls[0].toExternalForm().startsWith("file:"));
+//        assertTrue(urls[0].toExternalForm().indexOf("file1.txt") > 0);
 //        assertEquals(null, urls[1]);
 //    }
 //
@@ -524,19 +520,97 @@ public class FileUtilsTestCase extends FileBasedTestCase {
             getClass().getResource("/java/util/Collection.class"),
             objFile2);
 
-        assertEquals(false, FileUtils.contentEquals(objFile1, objFile2));
-        assertEquals(false, FileUtils.contentEquals(objFile1b, objFile2));
-        assertEquals(true, FileUtils.contentEquals(objFile1, objFile1b));
+        assertFalse(FileUtils.contentEquals(objFile1, objFile2));
+        assertFalse(FileUtils.contentEquals(objFile1b, objFile2));
+        assertTrue(FileUtils.contentEquals(objFile1, objFile1b));
 
-        assertEquals(true, FileUtils.contentEquals(objFile1, objFile1));
-        assertEquals(true, FileUtils.contentEquals(objFile1b, objFile1b));
-        assertEquals(true, FileUtils.contentEquals(objFile2, objFile2));
+        assertTrue(FileUtils.contentEquals(objFile1, objFile1));
+        assertTrue(FileUtils.contentEquals(objFile1b, objFile1b));
+        assertTrue(FileUtils.contentEquals(objFile2, objFile2));
 
         // Equal files
         file.createNewFile();
         file2.createNewFile();
-        assertEquals(true, FileUtils.contentEquals(file, file));
-        assertEquals(true, FileUtils.contentEquals(file, file2));
+        assertTrue(FileUtils.contentEquals(file, file));
+        assertTrue(FileUtils.contentEquals(file, file2));
+    }
+
+    public void testContentEqualsIgnoreEOL() throws Exception {
+        // Non-existent files
+        File file1 = new File(getTestDirectory(), getName());
+        File file2 = new File(getTestDirectory(), getName() + "2");
+        // both don't  exist
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file1, file1, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file1, file2, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file2, file2, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file2, file1, null));
+
+        // Directories
+        try {
+            FileUtils.contentEqualsIgnoreEOL(getTestDirectory(), getTestDirectory(), null);
+            fail("Comparing directories should fail with an IOException");
+        } catch (IOException ioe) {
+            //expected
+        }
+
+        // Different files
+        File tfile1 = new File(getTestDirectory(), getName() + ".txt1");
+        tfile1.deleteOnExit();
+        FileUtils.write(tfile1,"123\r");
+
+        File tfile2 = new File(getTestDirectory(), getName() + ".txt2");
+        tfile1.deleteOnExit();
+        FileUtils.write(tfile2,"123\n");
+
+        File tfile3 = new File(getTestDirectory(), getName() + ".collection");
+        tfile3.deleteOnExit();
+        FileUtils.write(tfile3,"123\r\n2");
+
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(tfile1, tfile1, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(tfile2, tfile2, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(tfile3, tfile3, null));
+
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(tfile1, tfile2, null));
+        assertFalse(FileUtils.contentEqualsIgnoreEOL(tfile1, tfile3, null));
+        assertFalse(FileUtils.contentEqualsIgnoreEOL(tfile2, tfile3, null));
+
+        URL urlCR = getClass().getResource("FileUtilsTestDataCR.dat");
+        assertNotNull(urlCR);
+        File cr = new File(urlCR.getPath());
+        assertTrue(cr.exists());
+
+        URL urlCRLF = getClass().getResource("FileUtilsTestDataCRLF.dat");
+        assertNotNull(urlCRLF);
+        File crlf = new File(urlCRLF.getPath());
+        assertTrue(crlf.exists());
+
+        URL urlLF = getClass().getResource("FileUtilsTestDataLF.dat");
+        assertNotNull(urlLF);
+        File lf = new File(urlLF.getPath());
+        assertTrue(lf.exists());
+
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(cr, cr, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(crlf, crlf, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(lf, lf, null));
+
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(cr, crlf, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(cr, lf, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(crlf, lf, null));
+
+        // Check the files behave OK when EOL is not ignored
+        assertTrue(FileUtils.contentEquals(cr, cr));
+        assertTrue(FileUtils.contentEquals(crlf, crlf));
+        assertTrue(FileUtils.contentEquals(lf, lf));
+
+        assertFalse(FileUtils.contentEquals(cr, crlf));
+        assertFalse(FileUtils.contentEquals(cr, lf));
+        assertFalse(FileUtils.contentEquals(crlf, lf));
+
+        // Equal files
+        file1.createNewFile();
+        file2.createNewFile();
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file1, file1, null));
+        assertTrue(FileUtils.contentEqualsIgnoreEOL(file1, file2, null));
     }
 
     // copyURLToFile
@@ -921,7 +995,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         assertTrue("Check exists", destDir.exists());
         assertTrue("Check exists", actualDestDir.exists());
         assertEquals("Check size", FileUtils.sizeOfDirectory(srcDir), FileUtils.sizeOfDirectory(actualDestDir));
-        assertEquals(true, new File(actualDestDir, "sub/A.txt").exists());
+        assertTrue(new File(actualDestDir, "sub/A.txt").exists());
         FileUtils.deleteDirectory(destDir);
     }
 
@@ -940,7 +1014,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         
         assertTrue("Check exists", destDir.exists());
         assertEquals("Check size", FileUtils.sizeOfDirectory(srcDir), FileUtils.sizeOfDirectory(destDir));
-        assertEquals(true, new File(destDir, "sub/A.txt").exists());
+        assertTrue(new File(destDir, "sub/A.txt").exists());
         FileUtils.deleteDirectory(destDir);
     }
 
@@ -959,7 +1033,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         FileUtils.copyDirectory(srcDir, destDir);
         
         assertEquals(FileUtils.sizeOfDirectory(srcDir), FileUtils.sizeOfDirectory(destDir));
-        assertEquals(true, new File(destDir, "sub/A.txt").exists());
+        assertTrue(new File(destDir, "sub/A.txt").exists());
     }
 
     public void testCopyDirectoryFiltered() throws Exception {
@@ -1053,8 +1127,8 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File childDir       = new File(parentDir, "child");
         createFilesForTestCopyDirectory(grandParentDir, parentDir, childDir);
 
-        long expectedCount = (LIST_WALKER.list(grandParentDir).size() * 2);
-        long expectedSize =  (FileUtils.sizeOfDirectory(grandParentDir) * 2);
+        long expectedCount = LIST_WALKER.list(grandParentDir).size() * 2;
+        long expectedSize =  FileUtils.sizeOfDirectory(grandParentDir) * 2;
         FileUtils.copyDirectory(grandParentDir, childDir);
         assertEquals(expectedCount, LIST_WALKER.list(grandParentDir).size());
         assertEquals(expectedSize, FileUtils.sizeOfDirectory(grandParentDir));
@@ -1152,8 +1226,9 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 
     public void testCopyFile1ToDir() throws Exception {
         File directory = new File(getTestDirectory(), "subdir");
-        if (!directory.exists())
+        if (!directory.exists()) {
             directory.mkdirs();
+        }
         File destination = new File(directory, testFile1.getName());
         
         //Thread.sleep(LAST_MODIFIED_DELAY);
@@ -1177,8 +1252,9 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 
     public void testCopyFile2ToDir() throws Exception {
         File directory = new File(getTestDirectory(), "subdir");
-        if (!directory.exists())
+        if (!directory.exists()) {
             directory.mkdirs();
+        }
         File destination = new File(directory, testFile1.getName());
         
         //Thread.sleep(LAST_MODIFIED_DELAY);
@@ -1233,7 +1309,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         assertTrue(file2.delete());
         
         String contents = FileUtils.readFileToString(new File(filename), "UTF-8");
-        assertTrue("FileUtils.fileRead()", contents.equals("This is a test"));
+        assertEquals("FileUtils.fileRead()", "This is a test", contents);
 
     }
 
@@ -1258,8 +1334,8 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         FileUtils.touch(file) ;
         assertEquals("FileUtils.touch() didn't empty the file.", 1, file.length());
         assertEquals("FileUtils.touch() changed lastModified", false, y2k == file.lastModified());
-        assertEquals("FileUtils.touch() changed lastModified to more than now-3s", true, file.lastModified() >= (now - 3000));
-        assertEquals("FileUtils.touch() changed lastModified to less than now+3s", true, file.lastModified() <= (now + 3000));
+        assertEquals("FileUtils.touch() changed lastModified to more than now-3s", true, file.lastModified() >= now - 3000);
+        assertEquals("FileUtils.touch() changed lastModified to less than now+3s", true, file.lastModified() <= now + 3000);
     }
 
     public void testListFiles() throws Exception {
@@ -1267,6 +1343,9 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File subDir = new File(srcDir, "list_test" );
         subDir.mkdir();
 
+        File subDir2 = new File(subDir, "subdir" );
+        subDir2.mkdir();
+
         String[] fileNames = {"a.txt", "b.txt", "c.txt", "d.txt", "e.txt", "f.txt"};
         int[] fileSizes = {123, 234, 345, 456, 678, 789};
 
@@ -1282,13 +1361,13 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         int count = files.size();
         Object[] fileObjs = files.toArray();
 
-        assertEquals(files.size(), fileNames.length);
+        assertEquals(fileNames.length, files.size());
 
         Map<String, String> foundFileNames = new HashMap<String, String>();
 
         for (int i = 0; i < count; ++i) {
             boolean found = false;
-            for(int j = 0; (( !found ) && (j < fileNames.length)); ++j) {
+            for(int j = 0; !found && j < fileNames.length; ++j) {
                 if ( fileNames[j].equals(((File) fileObjs[i]).getName())) {
                     foundFileNames.put(fileNames[j], fileNames[j]);
                     found = true;
@@ -1300,6 +1379,33 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 
         subDir.delete();
     }
+    
+    public void testListFilesWithDirs() throws IOException {
+    	File srcDir = getTestDirectory();
+    	
+    	File subDir1 = new File(srcDir, "subdir");
+    	subDir1.mkdir();
+    	
+    	File subDir2 = new File(subDir1, "subdir2");
+    	subDir2.mkdir();
+    	
+    	File someFile = new File(subDir2, "a.txt");
+    	createFile(someFile, 100);
+    	
+    	File subDir3 = new File(subDir2, "subdir3");
+    	subDir3.mkdir();
+    	
+    	Collection<File> files = FileUtils.listFilesAndDirs(subDir1, 
+    						new WildcardFileFilter("*.*"), new WildcardFileFilter("*"));
+    	
+    	assertEquals(4, files.size());
+    	assertTrue("Should contain the directory.", files.contains(subDir1));
+    	assertTrue("Should contain the directory.", files.contains(subDir2));
+    	assertTrue("Should contain the file.", files.contains(someFile));
+    	assertTrue("Should contain the directory.", files.contains(subDir3));
+    	
+    	subDir1.delete();
+    }
 
     public void testIterateFiles() throws Exception {
         File srcDir = getTestDirectory();
@@ -1324,7 +1430,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
             boolean found = false;
             String fileName = files.next().getName();
 
-            for (int j = 0; (( !found ) && (j < fileNames.length)); ++j) {
+            for (int j = 0; !found && j < fileNames.length; ++j) {
                 if ( fileNames[j].equals(fileName)) {
                     foundFileNames.put(fileNames[j], fileNames[j]);
                     found = true;
@@ -1336,6 +1442,36 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 
         subDir.delete();
     }
+    
+    public void testIterateFilesAndDirs() throws IOException {
+    	File srcDir = getTestDirectory();
+    	
+    	File subDir1 = new File(srcDir, "subdir");
+    	subDir1.mkdir();
+    	
+    	File subDir2 = new File(subDir1, "subdir2");
+    	subDir2.mkdir();
+    	
+    	File someFile = new File(subDir2, "a.txt");
+    	createFile(someFile, 100);
+    	
+    	File subDir3 = new File(subDir2, "subdir3");
+    	subDir3.mkdir();
+    	
+    	Collection<File> filesAndDirs = Arrays.asList(subDir1, subDir2, someFile, subDir3);
+    	
+    	int filesCount = 0;
+    	Iterator<File> files = FileUtils.iterateFilesAndDirs(subDir1, 
+                                                new WildcardFileFilter("*.*"),
+                                                new WildcardFileFilter("*"));
+        while (files.hasNext()) {
+            filesCount++;
+            File file = files.next();
+            assertTrue("Should contain the directory/file", filesAndDirs.contains(file));
+        }
+    	
+    	assertEquals(filesCount, filesAndDirs.size());
+    }
 
     public void testReadFileToStringWithDefaultEncoding() throws Exception {
         File file = new File(getTestDirectory(), "read.obj");
@@ -1410,7 +1546,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
 
     public void testWriteCharSequence2() throws Exception {
         File file = new File(getTestDirectory(), "write.txt");
-        FileUtils.write(file, "Hello /u1234", null);
+        FileUtils.write(file, "Hello /u1234", (String) null);
         byte[] text = "Hello /u1234".getBytes();
         assertEqualContent(text, file);
     }
@@ -1601,7 +1737,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File file = newFile("lines.txt");
         FileUtils.writeStringToFile(file, "This line was there before you...");
         
-        FileUtils.writeStringToFile(file, "this is brand new data", null, true);
+        FileUtils.writeStringToFile(file, "this is brand new data", (String) null, true);
 
         String expected = "This line was there before you..."
                 + "this is brand new data";
@@ -1613,7 +1749,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File file = newFile("lines.txt");
         FileUtils.writeStringToFile(file, "This line was there before you...");
         
-        FileUtils.writeStringToFile(file, "this is brand new data", null, false);
+        FileUtils.writeStringToFile(file, "this is brand new data", (String) null, false);
 
         String expected = "this is brand new data";
         String actual = FileUtils.readFileToString(file);
@@ -1647,7 +1783,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File file = newFile("lines.txt");
         FileUtils.writeStringToFile(file, "This line was there before you...");
         
-        FileUtils.write(file, "this is brand new data", null, true);
+        FileUtils.write(file, "this is brand new data", (String) null, true);
 
         String expected = "This line was there before you..."
             + "this is brand new data";
@@ -1659,7 +1795,7 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         File file = newFile("lines.txt");
         FileUtils.writeStringToFile(file, "This line was there before you...");
         
-        FileUtils.write(file, "this is brand new data", null, false);
+        FileUtils.write(file, "this is brand new data", (String) null, false);
 
         String expected = "this is brand new data";
         String actual = FileUtils.readFileToString(file);
@@ -2176,6 +2312,30 @@ public class FileUtilsTestCase extends FileBasedTestCase {
         }
     }
 
+    public void testIO300() throws Exception {
+        final File testDirectory = getTestDirectory();
+        File src = new File(testDirectory, "dir1");
+        File dest = new File(src,"dir2");
+        assertTrue(dest.mkdirs());
+        assertTrue(src.exists());
+        try {
+            FileUtils.moveDirectoryToDirectory(src, dest, false);
+            fail("expected IOException");
+        } catch (IOException ioe) {
+            // expected
+        }
+        assertTrue(src.exists());
+    }
+
+    public void testIO276() throws Exception {
+        File dir = new File("target", "IO276");
+        assertTrue(dir + " should not be present", dir.mkdirs());
+        File file = new File(dir, "IO276.txt");
+        assertTrue(file + " should not be present", file.createNewFile());
+        FileUtils.forceDeleteOnExit(dir);
+        // If this does not work, test will fail next time (assuming target is not cleaned)
+    }
+
     /**
      * DirectoryWalker implementation that recursively lists all files and directories.
      */
