@@ -16,6 +16,10 @@
  */
 package org.apache.commons.io.input;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -27,13 +31,12 @@ import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.commons.io.IOUtils;
-
-import junit.framework.TestCase;
+import org.junit.Ignore;
+import org.junit.Test;
 
 /**
- * @author Alejandro Abdelnur
  */
-public class XmlStreamReaderTest extends TestCase {
+public class XmlStreamReaderTest {
     private static final String XML5 = "xml-prolog-encoding-spaced-single-quotes";
     private static final String XML4 = "xml-prolog-encoding-single-quotes";
     private static final String XML3 = "xml-prolog-encoding-double-quotes";
@@ -72,10 +75,45 @@ public class XmlStreamReaderTest extends TestCase {
         }
     }
 
-    public void testRawNoBom() throws Exception {
+    @Test
+    public void testRawNoBomUsAscii() throws Exception {
         _testRawNoBomValid("US-ASCII");
+    }
+
+    @Test
+    public void testRawNoBomUtf8() throws Exception {
         _testRawNoBomValid("UTF-8");
+    }
+
+    @Test
+    public void testRawNoBomUtf16BE() throws Exception {
+        _testRawNoBomValid("UTF-16BE");
+    }
+
+    @Test
+    public void testRawNoBomUtf16LE() throws Exception {
+        _testRawNoBomValid("UTF-16LE");
+    }
+
+    @Test
+    @Ignore
+    public void testRawNoBomUtf32BE() throws Exception {
+        _testRawNoBomValid("UTF-32BE");
+    }
+
+    @Test
+    @Ignore
+    public void testRawNoBomUtf32LE() throws Exception {
+        _testRawNoBomValid("UTF-32LE");
+    }
+
+    @Test
+    public void testRawNoBomIso8859_1() throws Exception {
         _testRawNoBomValid("ISO-8859-1");
+    }
+
+    @Test
+    public void testRawNoBomCp1047() throws Exception {
         _testRawNoBomValid("CP1047");
     }
 
@@ -105,12 +143,9 @@ public class XmlStreamReaderTest extends TestCase {
         }
     }
 
-    public void testRawBom() throws Exception {
+    @Test
+    public void testRawBomUtf8() throws Exception {
         _testRawBomValid("UTF-8");
-        _testRawBomValid("UTF-16BE");
-        _testRawBomValid("UTF-16LE");
-        _testRawBomValid("UTF-16");
-
         _testRawBomInvalid("UTF-8-bom", "US-ASCII", "US-ASCII");
         _testRawBomInvalid("UTF-8-bom", "ISO-8859-1", "ISO-8859-1");
         _testRawBomInvalid("UTF-8-bom", "UTF-8", "UTF-16");
@@ -121,6 +156,27 @@ public class XmlStreamReaderTest extends TestCase {
         _testRawBomInvalid("UTF-16LE-bom", "UTF-16LE", "UTF-8");
     }
 
+    @Test
+    public void testRawBomUtf16() throws Exception {
+        _testRawBomValid("UTF-16BE");
+        _testRawBomValid("UTF-16LE");
+        _testRawBomValid("UTF-16");
+
+        _testRawBomInvalid("UTF-16BE-bom", "UTF-16BE", "UTF-16LE");
+        _testRawBomInvalid("UTF-16LE-bom", "UTF-16LE", "UTF-16BE");
+        _testRawBomInvalid("UTF-16LE-bom", "UTF-16LE", "UTF-8");
+    }
+
+    @Test
+    @Ignore
+    public void testRawBomUtf32() throws Exception {
+        _testRawBomValid("UTF-32BE");
+        _testRawBomValid("UTF-32LE");
+        _testRawBomValid("UTF-32");
+    }
+
+
+    @Test
     public void testHttp() throws Exception {
         // niallp 2010-10-06 - remove following 2 tests - I reinstated
         // checks for non-UTF-16 encodings (18 tests) and these failed 
@@ -221,8 +277,8 @@ public class XmlStreamReaderTest extends TestCase {
         _testHttpLenient("text/html;charset=UTF-16BE", "no-bom", "US-ASCII",
                 "UTF-8", "UTF-8");
     }
-
     
+    @Test
     public void testRawContent() throws Exception {
         String encoding = "UTF-8";
         String xml = getXML("no-bom", XML3, encoding, encoding);
@@ -232,6 +288,7 @@ public class XmlStreamReaderTest extends TestCase {
         assertEquals("Check content", xml, IOUtils.toString(xmlReader));
     }
 
+    @Test
     public void testHttpContent() throws Exception {
         String encoding = "UTF-8";
         String xml = getXML("no-bom", XML3, encoding, encoding);
@@ -244,14 +301,14 @@ public class XmlStreamReaderTest extends TestCase {
     public void _testAlternateDefaultEncoding(String cT, String bomEnc,
             String streamEnc, String prologEnc, String alternateEnc)
             throws Exception {
-        InputStream is = getXmlStream(bomEnc, (prologEnc == null) ? XML1
+        InputStream is = getXmlStream(bomEnc, prologEnc == null ? XML1
                 : XML3, streamEnc, prologEnc);
         XmlStreamReader xmlReader = new XmlStreamReader(is, cT, false, alternateEnc);
         if (!streamEnc.equals("UTF-16")) {
             // we can not assert things here because UTF-8, US-ASCII and
             // ISO-8859-1 look alike for the chars used for detection
             // (niallp 2010-10-06 - I re-instated the check below - the tests(6) passed)
-            String enc = (alternateEnc != null) ? alternateEnc : streamEnc;
+            String enc = alternateEnc != null ? alternateEnc : streamEnc;
             assertEquals(xmlReader.getEncoding(), enc);
         } else {
             //String enc = (alternateEnc != null) ? alternateEnc : streamEnc;
@@ -263,7 +320,7 @@ public class XmlStreamReaderTest extends TestCase {
     public void _testHttpValid(String cT, String bomEnc, String streamEnc,
             String prologEnc) throws Exception {
         InputStream is = getXmlStream(bomEnc,
-                (prologEnc == null) ? XML1 : XML3, streamEnc, prologEnc);
+                prologEnc == null ? XML1 : XML3, streamEnc, prologEnc);
         XmlStreamReader xmlReader = new XmlStreamReader(is, cT, false);
         if (!streamEnc.equals("UTF-16")) {
             // we can not assert things here because UTF-8, US-ASCII and
@@ -279,7 +336,7 @@ public class XmlStreamReaderTest extends TestCase {
     protected void _testHttpInvalid(String cT, String bomEnc, String streamEnc,
             String prologEnc) throws Exception {
         InputStream is = getXmlStream(bomEnc,
-                (prologEnc == null) ? XML2 : XML3, streamEnc, prologEnc);
+                prologEnc == null ? XML2 : XML3, streamEnc, prologEnc);
         try {
             new XmlStreamReader(is, cT, false);
             fail("It should have failed for HTTP Content-type " + cT + ", BOM "
@@ -293,7 +350,7 @@ public class XmlStreamReaderTest extends TestCase {
     protected void _testHttpLenient(String cT, String bomEnc, String streamEnc,
             String prologEnc, String shouldbe) throws Exception {
         InputStream is = getXmlStream(bomEnc,
-                (prologEnc == null) ? XML2 : XML3, streamEnc, prologEnc);
+                prologEnc == null ? XML2 : XML3, streamEnc, prologEnc);
         XmlStreamReader xmlReader = new XmlStreamReader(is, cT, true);
         assertEquals(xmlReader.getEncoding(), shouldbe);
     }
@@ -305,6 +362,7 @@ public class XmlStreamReaderTest extends TestCase {
             + "    <atom:title encoding='base64'><![CDATA\n"
             + "aW5nTGluZSIgLz4";
 
+    @Test
     public void testEncodingAttributeXML() throws Exception {
         InputStream is = new ByteArrayInputStream(ENCODING_ATTRIBUTE_XML
                 .getBytes("UTF-8"));
@@ -317,6 +375,8 @@ public class XmlStreamReaderTest extends TestCase {
     private static final int[] NO_BOM_BYTES = {};
     private static final int[] UTF_16BE_BOM_BYTES = { 0xFE, 0xFF };
     private static final int[] UTF_16LE_BOM_BYTES = { 0xFF, 0XFE };
+    private static final int[] UTF_32BE_BOM_BYTES = { 0x00, 0x00, 0xFE, 0xFF };
+    private static final int[] UTF_32LE_BOM_BYTES = { 0xFF, 0XFE, 0x00, 0x00 };
     private static final int[] UTF_8_BOM_BYTES = { 0xEF, 0xBB, 0xBF };
 
     private static final Map<String, int[]> BOMs = new HashMap<String, int[]>();
@@ -325,6 +385,8 @@ public class XmlStreamReaderTest extends TestCase {
         BOMs.put("no-bom", NO_BOM_BYTES);
         BOMs.put("UTF-16BE-bom", UTF_16BE_BOM_BYTES);
         BOMs.put("UTF-16LE-bom", UTF_16LE_BOM_BYTES);
+        BOMs.put("UTF-32BE-bom", UTF_32BE_BOM_BYTES);
+        BOMs.put("UTF-32LE-bom", UTF_32LE_BOM_BYTES);
         BOMs.put("UTF-16-bom", NO_BOM_BYTES); // it's added by the writer
         BOMs.put("UTF-8-bom", UTF_8_BOM_BYTES);
     }
@@ -366,8 +428,8 @@ public class XmlStreamReaderTest extends TestCase {
         if (bom == null) {
             bom = new int[0];
         }
-        for (int i = 0; i < bom.length; i++) {
-            baos.write(bom[i]);
+        for (int element : bom) {
+            baos.write(element);
         }
         Writer writer = new OutputStreamWriter(baos, streamEnc);
         String xmlDoc = getXML(bomType, xmlType, streamEnc, prologEnc);
